==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorTermFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TopologySelectorTermFluent<A extends io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public A setToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public A addToMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items);
  public A addAllToMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items);
  public A removeFromMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items);
  public A removeAllFromMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items);
  public A removeMatchingFromMatchLabelExpressions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatchLabelExpressions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> getMatchLabelExpressions();
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> buildMatchLabelExpressions();
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchLabelExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildFirstMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildLastMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  public java.lang.Boolean hasMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  public A withMatchLabelExpressions(java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> matchLabelExpressions);
  public A withMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... matchLabelExpressions);
  public java.lang.Boolean hasMatchLabelExpressions();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpressionLike(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> setNewMatchLabelExpressionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchLabelExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editFirstMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editLastMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  public interface MatchLabelExpressionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementFluent<io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<N>>{
    public N and();
    public N endMatchLabelExpression();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorTermFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TopologySelectorTermFluent<A extends io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public A setToMatchLabelExpressions(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public A addToMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items);
  public A addAllToMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items);
  public A removeFromMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... items);
  public A removeAllFromMatchLabelExpressions(java.util.Collection<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> items);
  public A removeMatchingFromMatchLabelExpressions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatchLabelExpressions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> getMatchLabelExpressions();
  public java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> buildMatchLabelExpressions();
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchLabelExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildFirstMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildLastMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement buildMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  public java.lang.Boolean hasMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  public A withMatchLabelExpressions(java.util.List<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement> matchLabelExpressions);
  public A withMatchLabelExpressions(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement... matchLabelExpressions);
  public java.lang.Boolean hasMatchLabelExpressions();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpressionLike(io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> setNewMatchLabelExpressionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirement item);
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchLabelExpression(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editFirstMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editLastMatchLabelExpression();
  public io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchingMatchLabelExpression(java.util.function.Predicate<io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MatchLabelExpressionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.TopologySelectorLabelRequirementFluent<io.fabric8.kubernetes.api.model.TopologySelectorTermFluent.MatchLabelExpressionsNested<N>>{
    public N and();
    public N endMatchLabelExpression();
    
  }
  
}
